@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,11 +32,11 @@ public:
     explicit AddresseeLineEditAkonadi(AddresseeLineEditManager *addressLineStatic);
     ~AddresseeLineEditAkonadi();
 
-    Akonadi::Session *akonadiSession();
+    Akonadi::Session *akonadiSession() const;
 
 private:
-    Akonadi::Session *m_akonadiSession;
-    AddresseeLineEditManager *mAddressLineStatic;
+    mutable Akonadi::Session *m_akonadiSession = nullptr;
+    AddresseeLineEditManager *mAddressLineStatic = nullptr;
 };
 }
 
